@@ -39,7 +39,7 @@ sub parse_speed_partial_grep {
 
 	my $lubina = RogueCurses::Messages::Lubina::lubina->new;
 	$lubina->work_on_nouns(@values);
-	return $lubina->probability;	
+	return $lubina->{probability};	
 }
 
 1;
